@@ -25,6 +25,7 @@
 G_BEGIN_DECLS
 
 #define GLIBTOP_SUID_CPU		(1 << GLIBTOP_SYSDEPS_CPU)
+#define GLIBTOP_SUID_DISK		0
 #define GLIBTOP_SUID_MEM		(1 << GLIBTOP_SYSDEPS_MEM)
 #define GLIBTOP_SUID_SWAP		(1 << GLIBTOP_SYSDEPS_SWAP)
 #define GLIBTOP_SUID_UPTIME		(1 << GLIBTOP_SYSDEPS_UPTIME)
@@ -47,6 +48,8 @@ G_BEGIN_DECLS
 #define GLIBTOP_SUID_PPP		(1 << GLIBTOP_SYSDEPS_PPP)
 #define GLIBTOP_SUID_PROC_WD		0
 #define GLIBTOP_SUID_PROC_AFFINITY	0
+#define GLIBTOP_SUID_PROC_OPEN_FILES	0
+#define GLIBTOP_SUID_PROC_IO		0
 
 G_END_DECLS
 
